clear all

***REGRESSIONS
***************************************
**TABLE
**Pre-market emotions and IPO returns
***************************************
import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)

egen ffi2_g = group(ffi2)
gen happyX = happy * ipo_firstday_ret_w
**Short-run
reg ipo_firstday_ret_w happy, r
estadd beta
eststo 

reg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 

areg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

areg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 


**Longer-run
foreach yvar in  ret_12month3 {
reg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
areg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 
}
esttab using "pre_market_ipo.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(happy happyX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(happy happyX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

***************************************
**TABLE
**INFORMATION CONTENT
***************************************

gen content_missing = 1 if happy_chat != . & happy_finance != . & happy_original != . & happy_diss != .
replace content_missing = . if happy_chat == . | happy_finance == . | happy_original == . | happy_diss == .


**Short-run
foreach var in "happy_chat" "happy_finance" "happy_original" "happy_diss" {
gen emo = `var'
areg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if content_missing == 1, absorb(ffi2_g) r
estadd beta
eststo 
drop emo 
}

**Longer-run
foreach var in "happy_chat" "happy_finance" "happy_original" "happy_diss" {
gen emo = `var'
gen emoX = `var' * ipo_firstday_ret_w
areg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year  if content_missing == 1, absorb(ffi2_g) r
estadd beta
eststo 
drop emo emoX 
}
esttab using "pre_market_ipo_content.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(emo emoX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_content_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(emo emoX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

***************************************
**TABLE
**HETEROGENEITY
***************************************
drop content_missing 
gen content_missing = 1 if happy_st != . & happy_lt != . & happy_pro != . & happy_nonpro != . & happy_funda!= . & happy_tech != .


**Short-run
foreach var in "happy_st" "happy_lt" "happy_pro" "happy_nonpro" "happy_funda" "happy_tech" {
gen emo = `var'
areg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if content_missing == 1, absorb(ffi2_g) r
estadd beta
eststo 
drop emo 
}
esttab using "pre_market_ipo_heterogeneity_panel_a.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(emo  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_heterogeneity_panel_a_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(emo  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

**Longer-run
foreach var in "happy_st" "happy_lt" "happy_pro" "happy_nonpro" "happy_funda" "happy_tech" {
gen emo = `var'
gen emoX = `var' * ipo_firstday_ret_w
areg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year  if content_missing == 1, absorb(ffi2_g) r
estadd beta
eststo 
drop emo emoX 
}
esttab using "pre_market_ipo_heterogeneity_panel_b.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(emo emoX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_heterogeneity_panel_b_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(emo emoX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

******VALENCE
gen valenceX = valence * ipo_firstday_ret_w

**Short-run
reg ipo_firstday_ret_w valence, r
estadd beta
eststo 

reg ipo_firstday_ret_w valence avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 

areg ipo_firstday_ret_w valence avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

areg ipo_firstday_ret_w valence avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 

**Longer-run
foreach yvar in  ret_12month3 {
reg `yvar'_adj_w valence valenceX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg `yvar'_adj_w valence valenceX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
areg `yvar'_adj_w valence valenceX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 
}
esttab using "pre_market_ipo_valence.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(valence valenceX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_valence_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(valence valenceX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear


***************************************
**TABLE
**SENSITIVITY
***************************************
import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)
egen ffi2_g = group(ffi2)

**Short-run
**WINSORIZATION
gen emo = happy 
reg ipo_firstday_ret_2w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 
areg ipo_firstday_ret_2w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**NO WINSORIZATION
reg ipo_firstday_ret emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 
areg ipo_firstday_ret emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**FOLLOWER WEIGHTING
drop emo
gen emo = happy_wmean
reg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 
areg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**ALTERNATIVE MODEL
drop emo
gen emo = happy_twitter
reg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 
areg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**TWITTER DATA
import delimited "ipo_emotions_crsp.csv", clear
ffind sic, newvar(ffi2) type(48)
egen ffi2_g = group(ffi2)
gen emo = happy
reg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 
areg ipo_firstday_ret_w emo avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

esttab using "pre_market_ipo_sensitivity_panel_a.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(emo  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

**Longer-run
import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)
egen ffi2_g = group(ffi2)

**WINSORIZATION
gen emo = happy
gen emoX = happy * ipo_firstday_ret_w
reg ret_12month3_adj_2w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg ret_12month3_adj_2w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**NO WINSORIZATION
reg ret_12month3_adj emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg ret_12month3_adj emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
**FOLLOWER WEIGHTING
drop emoX emo
gen emo = happy_wmean
gen emoX = happy_wmean * ipo_firstday_ret_w

reg ret_12month3_adj_w emoX emo ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg ret_12month3_adj_w emoX emo ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

**ALTERNATIVE MODEL
drop emoX emo
gen emo = happy_twitter
gen emoX = happy_twitter * ipo_firstday_ret_w

reg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

**TWITTER DATA
import delimited "ipo_emotions_crsp.csv", clear
ffind sic, newvar(ffi2) type(48)
egen ffi2_g = group(ffi2)
gen emo = happy
gen emoX = happy * ipo_firstday_ret_w

reg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg ret_12month3_adj_w emo emoX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

esttab using "pre_market_ipo_sensitivity_panel_b.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(emo emoX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

***APPENDIX
gen happyX = happy * ipo_firstday_ret_w
**Short-run
reg ipo_firstday_ret_w happy, r
estadd beta
eststo 

reg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 

areg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

areg ipo_firstday_ret_w happy avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 

**Longer-run
foreach yvar in  ret_12month3 {
reg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
areg `yvar'_adj_w happy happyX ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 
}
esttab using "pre_market_ipo_twitter.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep(happy happyX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_twitter_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep(happy happyX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

***************************************
**TABLE
**TWITTER SAMPLE
***************************************
import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)
egen ffi2_g = group(ffi2)
**EMOTIONS
global emotions happy sad hate  fear surprise
global emotions_X happyX sadX hateX fearX surpriseX

foreach var in $emotions {
label variable `var' `var'
gen `var'X = `var' * ipo_firstday_ret_w
}

**Short-run
reg ipo_firstday_ret_w $emotions, r
estadd beta
eststo 

reg ipo_firstday_ret_w $emotions avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w, r
estadd beta
eststo 

areg ipo_firstday_ret_w $emotions avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 

areg ipo_firstday_ret_w $emotions avg_past_firstday_td90 offer_amount mktrf smb hml rmw cma ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 

**Longer-run
foreach yvar in  ret_12month3 {
reg `yvar'_adj_w $emotions ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi, r
estadd beta
eststo 
areg `yvar'_adj_w $emotions ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year, absorb(ffi2_g) r
estadd beta
eststo 
areg `yvar'_adj_w $emotions ipo_firstday_ret_w avg_past_firstday_td90 offer_amount ret_lag1month_ffi_w i.year if num_obs >= 10, absorb(ffi2_g) r
estadd beta
eststo 
}
esttab using "pre_market_ipo_emotions_seven.tex", s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First-Day IPO Returns \label{tab:pre_market}) b(4) keep($emotions $emotionsX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount _cons) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
esttab using "pre_market_ipo_emotions_seven_beta.tex", cells(beta) s(N r2, label("Observations" "\$R^2\$")) label title(Pre-Market Emotions and First Week IPO Returns: Standardized Effects \label{tab:pre_market}) b(4) keep($emotions $emotionsX ipo_firstday_ret_w  avg_past_firstday_td90 offer_amount) se star(* 0.10 ** 0.05 *** 0.01) addnotes("") width(\hsize) replace
eststo clear

