clear all

global corr_vars valence happy sad hate surprise fear ret_12month3_adj_w offer_amount ipo_firstday_ret_w

******************************
**IPO TABULATION
******************************
import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)

******************************
**DISTRIBUTION OF CRSP VS SAMPLE
**ACROSS INDUSTRIES
******************************
**Tabulate industries 
estpost tabulate ffi2 [w=num_obs]
eststo event_tab 
estpost tabulate ffi2
eststo event_tab_q 

import delimited "stock_panel.csv", clear
estpost tabulate ffi2
eststo crsp_tab

esttab using summary_industry_tab.tex, varlabels(`e(labels)') label cell(pct(fmt(2))) unstack replace
eststo clear 

import delimited "ipo_emotions_crsp_sw.csv", clear
ffind sic, newvar(ffi2) type(48)

******************************
**DISTRIBUTION SAMPLE
**OVER TIME
******************************
gen my_counts = 1 
estpost tabstat my_counts, by(year) statistics(sum) columns(statistics) listwise
eststo event_q
estpost tabstat num_obs, by(year) statistics(sum) columns(statistics) listwise
eststo event_q_sum
esttab using summary_year_tab.tex, main(sum) noobs unstack label replace
eststo clear 

******************************
**CORRELATION MATRIX
******************************
estpost corr $corr_vars, matrix bonferroni
eststo correlation
esttab correlation using correlations.tex, label unstack compress b(2) replace
eststo clear 

******************************
**  Summary Statistics 
******************************
**IPO sample
global emotions valence happy sad anger disgust fear surprise
**Label variables 
foreach var in "valence" "happy" "sad" "anger" "disgust" "fear" "surprise" {
label variable `var' `var'
}
drop offer_amount
gen offer_amount = ipoprice * ipo_shares 
replace offer_amount = offer_amount / 1000000
replace ipo_shares = ipo_shares / 1000000
eststo regular: estpost summarize $emotions num_obs num_users ipo_shares offer_amount ipo_firstday_ret ipoprice  ret_12month3 ret_12month3_adj
esttab regular using summary_tab_ipo.tex, label replace main(mean %6.3f) aux(sd) nonumber nostar ///
title(Summary Statistics) nonotes addn(Standard deviations in parentheses.)
eststo clear


clear all

******************************
**IPO TABULATION
******************************
import delimited "ipo_emotions_crsp.csv", clear
ffind sic, newvar(ffi2) type(48)

******************************
**DISTRIBUTION OF CRSP VS SAMPLE
**ACROSS INDUSTRIES
******************************
**Tabulate industries 
estpost tabulate ffi [w=num_obs]
eststo event_tab 
estpost tabulate ffi
eststo event_tab_q 
import delimited "stock_panel.csv", clear
estpost tabulate ffi
eststo crsp_tab

esttab using summary_industry_tab_tw.tex, varlabels(`e(labels)') label cell(pct(fmt(2))) unstack replace
eststo clear 

import delimited "ipo_emotions_crsp.csv", clear
ffind sic, newvar(ffi2) type(48)

******************************
**DISTRIBUTION SAMPLE
**OVER TIME
******************************
gen my_counts = 1 
estpost tabstat my_counts, by(year) statistics(sum) columns(statistics) listwise
eststo event_q
estpost tabstat num_obs, by(year) statistics(sum) columns(statistics) listwise
eststo event_q_sum
esttab using summary_year_tab_tw.tex, main(sum) noobs unstack label replace
eststo clear 

******************************
**CORRELATION MATRIX
******************************
estpost corr $corr_vars, matrix bonferroni
eststo correlation
esttab correlation using correlations_tw.tex, label unstack compress b(2) replace
eststo clear 

******************************
**  Summary Statistics 
******************************
**IPO sample
global emotions valence happy sad anger disgust fear surprise
**Label variables 
foreach var in "valence" "happy" "sad" "anger" "disgust" "fear" "surprise" {
label variable `var' `var'
}
drop offer_amount
gen offer_amount = ipoprice * ipo_shares 
replace offer_amount = offer_amount / 1000000
replace ipo_shares = ipo_shares / 1000000
eststo regular: estpost summarize $emotions num_obs num_users ipo_shares offer_amount ipo_firstday_ret ipoprice  ret_12month3 ret_12month3_adj
esttab regular using summary_tab_ipo_tw.tex, label replace main(mean %6.3f) aux(sd) nonumber nostar ///
title(Summary Statistics) nonotes addn(Standard deviations in parentheses.)
eststo clear